@@ -21,10 +21,10 @@ with open(join(folder, "deciphon_api", "sched", "interface.h"), "r") as f:
 ffibuilder.set_source(
     "deciphon_api.sched.cffi",
     """
-        #include "sched/sched.h"
+    #include "sched/sched.h"
     """,
     language="c",
-    libraries=["sched"],
+    libraries=["sched", "c_toolbelt"],
     library_dirs=[".ext_deps/lib"],
     include_dirs=[".ext_deps/include"],
 )
